"""Common utilities and base functionalities for all skills in the Private Assistant ecosystem."""

from .base_skill import BaseSkill
from .intent import (
    Alert,
    ClassifiedIntent,
    ClientRequest,
    Entity,
    EntityType,
    IntentRequest,
    IntentType,
    RecentAction,
    Response,
    SkillContext,
)
from .skill_config import SkillConfig
from .skill_logger import LoggerConfig, SkillLogger

# Single __all__ declaration with all public exports
__all__ = [
    "Alert",
    "BaseSkill",
    "ClassifiedIntent",
    "ClientRequest",
    "Entity",
    "EntityType",
    "IntentRequest",
    "IntentType",
    "LoggerConfig",
    "RecentAction",
    "Response",
    "SkillConfig",
    "SkillContext",
    "SkillLogger",
]
